/*!
  @header ECXMLControlRuleSelector
  @abstract Module of Encore
 
  @availability OS X, GNUstep
  @copyright 2004, 2005, 2006 Oliver Langer

  Author: Oliver Langer

  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Lesser General Public
  License as published by the Free Software Foundation; either
  version 2.1 of the License, or (at your option) any later version.

  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Lesser General Public License for more details.

  You should have received a copy of the GNU Lesser General Public
  License along with this library; if not, write to the Free Software
  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA

  <pre>
  -------------------------------------------------------------------------
  Modification history

  27.11.05 ola     initial version
  22.08.06 ola     license changed
  -------------------------------------------------------------------------
  </pre>
*/

#include <ECXMLControlRuleSelector.h>

@implementation ECXMLControlRuleSelector

- init {
  self = [super init];

  self->rules = [[NSMutableArray alloc] init];
  self->eventIdToRuleMap = [[ECKeyToListMap alloc] init];
    
  return self;
}


- (void) dealloc {
  if( nil != self->rules ) {
    [self->rules release];
  }
  
  if( nil != eventIdToRuleMap ) {
    [self->eventIdToRuleMap release];
  }
  
  [super dealloc];
}


- addRule: (id <ECXMLControlRule>) newRule forEvent: (id) anEvent {
  [self->eventIdToRuleMap addListItem: newRule forKey: anEvent];
  
  return self;
}


- performRulesForContext: (ECXMLControlContext *) aContext {
  id <ECIterator> iterator;
  
  EC_AUTORELEASEPOOL_BEGIN
    iterator = [eventIdToRuleMap listItemsOfKey: [[aContext event] eventId]];
    if( nil != iterator ) {
      while( [iterator hasNext] ) {
        id <ECXMLControlRule> current = [iterator next];
        if( [current mayActOn: aContext] ) {
          if( [current actOn: aContext] ) {
            break;
          }
        }
      }
    }
  EC_AUTORELEASEPOOL_END
  
  return self;
}
@end
